@@ -19,15 +19,16 @@ from itertools import count
 
 from . import serialization
 from .entity import Exchange, Queue
+from .exceptions import StdChannelError
 from .log import Log
 from .messaging import Consumer as _Consumer
 from .utils import uuid
 
-__all__ = ["Broadcast", "entry_to_queue", "maybe_declare", "uuid",
-           "itermessages", "send_reply", "isend_reply",
-           "collect_replies", "insured", "ipublish"]
+__all__ = ['Broadcast', 'maybe_declare', 'uuid',
+           'itermessages', 'send_reply', 'isend_reply',
+           'collect_replies', 'insured', 'ipublish']
 
-insured_logger = Log("kombu.insurance")
+insured_logger = Log('kombu.insurance')
 
 
 class Broadcast(Queue):
@@ -47,10 +48,10 @@ class Broadcast(Queue):
 
     def __init__(self, name=None, queue=None, **kwargs):
         return super(Broadcast, self).__init__(
-                    name=queue or "bcast.%s" % (uuid(), ),
-                    **dict({"alias": name,
-                            "auto_delete": True,
-                            "exchange": Exchange(name, type="fanout"),
+                    name=queue or 'bcast.%s' % (uuid(), ),
+                    **dict({'alias': name,
+                            'auto_delete': True,
+                            'exchange': Exchange(name, type='fanout'),
                            }, **kwargs))
 
 
@@ -58,27 +59,30 @@ def declaration_cached(entity, channel):
     return entity in channel.connection.client.declared_entities
 
 
-def maybe_declare(entity, channel, retry=False, **retry_policy):
+def maybe_declare(entity, channel=None, retry=False, **retry_policy):
+    if not entity.is_bound:
+        assert channel
+        entity = entity.bind(channel)
     if retry:
-        return _imaybe_declare(entity, channel, **retry_policy)
-    return _maybe_declare(entity, channel)
+        return _imaybe_declare(entity, **retry_policy)
+    return _maybe_declare(entity)
 
 
-def _maybe_declare(entity, channel):
+def _maybe_declare(entity):
+    channel = entity.channel
+    if not channel.connection:
+        raise StdChannelError("channel disconnected")
     declared = channel.connection.client.declared_entities
     if entity not in declared:
-        if not entity.is_bound:
-            entity = entity.bind(channel)
         entity.declare()
         declared.add(entity)
         return True
     return False
 
 
-def _imaybe_declare(entity, channel, **retry_policy):
-    entity = entity(channel)
-    return channel.connection.client.ensure(entity, _maybe_declare,
-                             **retry_policy)(entity, channel)
+def _imaybe_declare(entity, **retry_policy):
+    return entity.channel.connection.client.ensure(entity, _maybe_declare,
+                             **retry_policy)(entity)
 
 
 def drain_consumer(consumer, limit=1, timeout=None, callbacks=None):
@@ -150,9 +154,9 @@ def send_reply(exchange, req, msg, producer=None, **props):
     serializer = serialization.registry.type_to_name[content_type]
     maybe_declare(exchange, producer.channel)
     producer.publish(msg, exchange=exchange,
-            **dict({"routing_key": req.properties["reply_to"],
-                    "correlation_id": req.properties.get("correlation_id"),
-                    "serializer": serializer},
+            **dict({'routing_key': req.properties['reply_to'],
+                    'correlation_id': req.properties.get('correlation_id'),
+                    'serializer': serializer},
                     **props))
 
 
@@ -162,7 +166,7 @@ def isend_reply(pool, exchange, req, msg, props, **retry_policy):
 
 
 def collect_replies(conn, channel, queue, *args, **kwargs):
-    no_ack = kwargs.setdefault("no_ack", True)
+    no_ack = kwargs.setdefault('no_ack', True)
     received = False
     for body, message in itermessages(conn, channel, queue, *args, **kwargs):
         if not no_ack:
@@ -175,7 +179,7 @@ def collect_replies(conn, channel, queue, *args, **kwargs):
 
 def _ensure_errback(exc, interval):
     insured_logger.error(
-        "Connection error: %r. Retry in %ss\n" % (exc, interval),
+        'Connection error: %r. Retry in %ss\n' % (exc, interval),
             exc_info=True)
 
 
@@ -218,42 +222,4 @@ def ipublish(pool, fun, args=(), kwargs={}, errback=None, on_revive=None,
 
 
 def entry_to_queue(queue, **options):
-    binding_key = options.get("binding_key") or options.get("routing_key")
-
-    e_durable = options.get("exchange_durable")
-    if e_durable is None:
-        e_durable = options.get("durable")
-
-    e_auto_delete = options.get("exchange_auto_delete")
-    if e_auto_delete is None:
-        e_auto_delete = options.get("auto_delete")
-
-    q_durable = options.get("queue_durable")
-    if q_durable is None:
-        q_durable = options.get("durable")
-
-    q_auto_delete = options.get("queue_auto_delete")
-    if q_auto_delete is None:
-        q_auto_delete = options.get("auto_delete")
-
-    e_arguments = options.get("exchange_arguments")
-    q_arguments = options.get("queue_arguments")
-    b_arguments = options.get("binding_arguments")
-
-    exchange = Exchange(options.get("exchange"),
-                        type=options.get("exchange_type"),
-                        delivery_mode=options.get("delivery_mode"),
-                        routing_key=options.get("routing_key"),
-                        durable=e_durable,
-                        auto_delete=e_auto_delete,
-                        arguments=e_arguments)
-
-    return Queue(queue,
-                 exchange=exchange,
-                 routing_key=binding_key,
-                 durable=q_durable,
-                 exclusive=options.get("exclusive"),
-                 auto_delete=q_auto_delete,
-                 no_ack=options.get("no_ack"),
-                 queue_arguments=q_arguments,
-                 binding_arguments=b_arguments)
+    return Queue.from_dict(queue, **options)
