@@ -14,15 +14,15 @@ class test_sqlalchemy(TestCase):
         try:
             import sqlalchemy  # noqa
         except ImportError:
-            raise SkipTest("sqlalchemy not installed")
-        with patch("kombu.transport.sqlalchemy.Channel._open"):
-            url = "sqlalchemy+sqlite://celerydb.sqlite"
+            raise SkipTest('sqlalchemy not installed')
+        with patch('kombu.transport.sqlalchemy.Channel._open'):
+            url = 'sqlalchemy+sqlite://celerydb.sqlite'
             BrokerConnection(url).connect()
 
-            url = "sqla+sqlite://celerydb.sqlite"
+            url = 'sqla+sqlite://celerydb.sqlite'
             BrokerConnection(url).connect()
 
             # Should prevent regression fixed by f187ccd
-            url = "sqlb+sqlite://celerydb.sqlite"
+            url = 'sqlb+sqlite://celerydb.sqlite'
             with self.assertRaises(KeyError):
                 BrokerConnection(url).connect()
